pycocoa.geometry.Rect4

Package pycocoa :: Module geometry :: Class Rect4 |
[frames] | no frames]

# Class Rect4

              object --+
                       |
    internals._Objectype --+
                           |
            baseTypes._Type0 --+
                               |
                            Rect --+
                                   |
                                  Rect4

Python Type, like Rect, but signature as ObjC NSRect4_t.

Instance Methods
__init__(self, x=0, y=0, width=0, height=0) New Rect4 from keyword arguments. |
Inherited from `Rect`: `__str__` Inherited from `baseTypes._Type0`: `__repr__`, `type2strepr` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `Rect`: `bottom`, `bottomleft`, `bottomright`, `center`, `height`, `left`, `lowerleft`, `lowerright`, `origin`, `ratio`, `rect`, `rect4`, `right`, `size`, `top`, `topleft`, `topright`, `upperleft`, `upperright`, `width`, `x`, `y` Inherited from `baseTypes._Type0`: `NS`, `NSDelegate` Inherited from `internals._Objectype`: `typename` Inherited from `object`: `__class__`

Method Details

### __init__(self, x=0, y=0, width=0, height=0) (Constructor) |
New Rect4 from keyword arguments. Overrides: object.__init__